%{!?kernel_version: %{expand: %%define kernel_version %(uname -r|sed -e 's/EL.*$/EL/g')}}
%{!?kversionreltag: %{expand: %%define kversionreltag %(echo %{kernel_version} |sed -e 's/-/./g')}}
%{!?type: %{expand: %define type %(uname -r | sed -e 's/.*EL//g' | sed -e 's/^$/up/g')}}

# On RHEL 4, up type has no tag
%if "%{type}" != "up"
%define releasetag %{kversionreltag}.%{type}
%define kernel_dir %{kernel_version}%{type}
%define kernel_devel kernel-%{type}-devel
%else
%define releasetag %{kversionreltag}
%define kernel_dir %{kernel_version}
%define kernel_devel kernel-devel
%endif

# Keep the modKey def identical to that in util.sh-PMWV.*
%define modKey 'PMWV|%{type}|vmmemctl'
%define vmwDB /usr/lib/vmware-tools/moduleScripts/vmmemctl/vmware-db.pl --os=linux,rhel,4
%define vmwPMWV /usr/lib/vmware-tools/moduleScripts/vmmemctl/vmware-pmwv.pl --os=linux,rhel,4 --release=%{kernel_dir} --build 1399439 --modKey %{modKey}
%define kmp_version %version

Name:         vmware-tools-vmmemctl
BuildRequires: %{kernel_devel} gcc
Vendor:       VMware
License:      GPL
Group:        System/Kernel
Summary:      Contains the source needed to build the vmmemctl kernel module package (kmp) for the running kernel.
Epoch:        0
Version:      1.2.1.2
Release:      4.el4
BuildRoot:    %{_tmppath}/%{name}-%{version}-build
Source1:      vmmemctl-configModule.tar.gz

Source0:      vmmemctl.tar

%prep
%setup -n vmmemctl-only

%build
make clean
make

# NOTE: RHEL 4 has MODVERSIONS enabled but does not generate the module.symvers
#       file we would need in order to properly propagate symbol versions
#       in-between interdependent kernel modules.  See bug 568405 for more info.
if [ "vmmemctl" = "vsock" -o "vmmemctl" = "vmhgfs" ]; then
   echo
   echo
   echo "Please ignore the \"VMCI_ ... undefined!\" warnings generated by the build system."
   echo "The vmmemctl module will load and function properly despite those warnings."
   echo
   echo
fi

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
# The following command copies our newly build kernel module to a known
# location.  Unfortunately sometimes the kmod source build places the kmods
# in inconsistent locations.
cp ../vmmemctl.o . 2>/dev/null || true
cp driver-%{kernel_version}/vmmemctl-xxx-%{kernel_version} ./vmmemctl.o 2>/dev/null || true

# Install kernel module
install -m 644 -D vmmemctl.o $RPM_BUILD_ROOT/lib/modules/%{kernel_dir}/extra/%{name}/vmmemctl.ko
# Install common files
cd $RPM_BUILD_ROOT && tar xzf %{SOURCE1}

%description
 This package enables you to build binary kernel module packages (kmps) for vmmemctl.  The vmmemctl module expands and contracts, allocating and freeing memory respectively within the guest OS. This causes the guest to invoke its memory management routines, allowing the ESX host to reclaim memory as memory pressure increases within the ESX host. Using this module allows for efficient memory over commitment on ESX hosts by forcing the guests to page out memory instead of forcing the host to page out memory.

%package common
Summary:      Contains the common files used by all the vmmemctl kernel module packages (kmps).
Group:        System/Kernel
Requires:     perl
Requires:     vmware-tools-foundation >= 0:8.6.0
Release:      4.el4
Version:      9.4.0

%description common
 This package contains the common system configuration and scripts responsible for loading the vmmemctl kernel module.  The vmmemctl module expands and contracts, allocating and freeing memory respectively within the guest OS. This causes the guest to invoke its memory management routines, allowing the ESX host to reclaim memory as memory pressure increases within the ESX host. Using this module allows for efficient memory over commitment on ESX hosts by forcing the guests to page out memory instead of forcing the host to page out memory.

%package kmp-%{type}
Summary:      The vmmemctl kernel module built for the %{kernel_version} kernel.
Group:        System/Kernel
Requires:     vmware-tools-vmmemctl-common
Requires:     vmware-tools-foundation >= 0:8.6.0
Provides:     vmware-tools-vmmemctl-kmp
Release:      %{kversionreltag}.4.el4


%description kmp-%{type}
 This package contains a pre-compiled vmmemctl module for use with the %{kernel_version} kernel.   The vmmemctl module expands and contracts, allocating and freeing memory respectively within the guest OS. This causes the guest to invoke its memory management routines, allowing the ESX host to reclaim memory as memory pressure increases within the ESX host. Using this module allows for efficient memory over commitment on ESX hosts by forcing the guests to page out memory instead of forcing the host to page out memory.

%pre kmp-%{type}
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   # If the type matches, stop the init script
   kmodType=`uname -r | sed -e 's/.*EL//g'`
   if [ -z "$kmodType" ]; then
      kmodType=up
   fi
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vmmemctl stop
   fi

   %{vmwPMWV} --rpmSection=Postun
fi

# Configure
%{vmwPMWV} --rpmSection=Pre

%pre common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vmmemctl ]; then
      /sbin/chkconfig vmmemctl off
   fi
   /usr/lib/vmware-tools/moduleScripts/vmmemctl/vmware-deconfig.pl --os=linux,rhel,4 --toDeconfigure=vmmemctl
   /usr/lib/vmware-tools/moduleScripts/vmmemctl/vmware-db.pl --os=linux,rhel,4 --dbDelAnswer VMMEMCTL_NAME
fi

%post common
/usr/lib/vmware-tools/moduleScripts/vmmemctl/vmware-db.pl --os=linux,rhel,4 --dbAddAnswer VMMEMCTL_NAME,vmmemctl
/usr/lib/vmware-tools/moduleScripts/vmmemctl/vmware-config.pl --os=linux,rhel,4 --toConfigure=vmmemctl
if [ -e /etc/init.d/vmmemctl ]; then
   /sbin/chkconfig vmmemctl on
fi

%post kmp-%{type}
# Configure
# Invoke the PMWV Post Section
%{vmwPMWV} --rpmSection=Post --baseMod=/lib/modules/%{kernel_dir}/extra/%{name}/vmmemctl.ko

# If the type matches, start the init script
kmodType=`uname -r | sed -e 's/.*EL//g'`
if [ -z "$kmodType" ]; then
   kmodType=up
fi
if [ "$kmodType" = "%{type}" ]; then
   /etc/init.d/vmmemctl start
fi

%preun common
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   if [ -e /etc/init.d/vmmemctl ]; then
      /sbin/chkconfig vmmemctl off
   fi
   /usr/lib/vmware-tools/moduleScripts/vmmemctl/vmware-deconfig.pl --os=linux,rhel,4 --toDeconfigure=vmmemctl
   /usr/lib/vmware-tools/moduleScripts/vmmemctl/vmware-db.pl --os=linux,rhel,4 --dbDelAnswer VMMEMCTL_NAME
fi

%preun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   # If the type matches, stop the init script
   kmodType=`uname -r | sed -e 's/.*EL//g'`
   if [ -z "$kmodType" ]; then
      kmodType=up
   fi
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vmmemctl stop
   fi
fi

%postun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   %{vmwPMWV} --rpmSection=Postun
fi

%files common
%defattr(-, root, root, -)
/usr/lib/vmware-tools/moduleScripts/vmmemctl/vmware-pmwv.pl
/usr/lib/vmware-tools/moduleScripts/vmmemctl/vmware-deconfig.pl
/usr/lib/vmware-tools/moduleScripts/vmmemctl/vmware-db.pl
/usr/lib/vmware-tools/moduleScripts/vmmemctl/vmware-config.pl
/etc/rc.d/init.d/vmmemctl

%files kmp-%{type}
%defattr(-, root, root, -)
/lib/modules/%{kernel_dir}/extra/%{name}/vmmemctl.ko


